SIMILAR_NAMES: dict[str, int] = {
    "鞍山": 210300000000,
    "鞍山市": 210300000000,
    "马鞍山": 340500000000,
    "马鞍山市": 340500000000,
}

ZXCITIES: dict[str, str] = {
    "北京": "北京市",
    "天津": "天津市",
    "上海": "上海市",
    "重庆": "重庆市",
}

SAME_NAMES: dict[str, tuple[str, str]] = {
    "吉林": ("吉林市", "吉林市"),
    "承德": ("承德市", "承德县"),
    "铁岭": ("铁岭市", "铁岭县"),
    "抚顺": ("抚顺市", "抚顺县"),
    "辽阳": ("辽阳市", "辽阳县"),
    "朝阳": ("朝阳市", "朝阳县"),
    "阜新": ("阜新市", "阜新蒙古族自治县"),
    "本溪": ("本溪市", "本溪满族自治县"),
    "通化": ("通化市", "通化县"),
    "南昌": ("南昌市", "南昌县"),
    "吉安": ("吉安市", "吉安县"),
    "安阳": ("安阳市", "安阳县"),
    "新乡": ("新乡市", "新乡县"),
    "濮阳": ("濮阳市", "濮阳县"),
    "长沙": ("长沙市", "长沙县"),
    "湘潭": ("湘潭市", "湘潭县"),
    "邵阳": ("邵阳市", "邵阳县"),
    "岳阳": ("岳阳市", "岳阳县"),
    "衡阳": ("衡阳市", "衡阳县"),
    "临夏": ("临夏回族自治州", "临夏市"),
    "乌鲁木齐": ("乌鲁木齐市", "乌鲁木齐县"),
    "和田": ("和田市", "和田县"),
    "伊宁": ("伊宁市", "伊宁县"),
    "黄山": ("黄山市", "黄山区"),
    "文山": ("文山壮族苗族自治州", "文山市"),
}
